@@ -18,11 +18,13 @@ cshp <- function(date=NA, useGW=TRUE) {
 	if (is.na(date)) {
 		cshp.full
 	} else if (useGW) {
+	  	cshp.full <- cshp.full[cshp.full$GWCODE>=0,]
 		startdate <- as.Date(paste(cshp.full$GWSYEAR, cshp.full$GWSMONTH, cshp.full$GWSDAY, sep="-"))
 		enddate <- as.Date(paste(cshp.full$GWEYEAR, cshp.full$GWEMONTH, cshp.full$GWEDAY, sep="-"))
 		cshp.part <- cshp.full[startdate < date & enddate >= date,]
 		cshp.part
 	} else {
+		cshp.full <- cshp.full[cshp.full$COWCODE>=0,]
 		startdate <- as.Date(paste(cshp.full$COWSYEAR, cshp.full$COWSMONTH, cshp.full$COWSDAY, sep="-"))
 		enddate <- as.Date(paste(cshp.full$COWEYEAR, cshp.full$COWEMONTH, cshp.full$COWEDAY, sep="-"))
 		cshp.part <- cshp.full[startdate < date & enddate >= date,]
